// Pitch.h - Declarations for pitch-finding functions
// Copyright 2006 Chad Berchek

#ifndef PITCH_H
#define PITCH_H

// Structure to hold a bin index that has been found by a search. Includes
// a flag to indicate whether the bin is valid, usually indicating whether
// or not the search was successful.
struct foundBin {
	bool isValid;
	unsigned int binIndex;
};

// Structure to hold return values from findFundamental function. Includes
// frequency and error code.
struct foundFund {
	double frequency;
	int errorCode;
};

foundBin findPeak(const double * const ampl, const unsigned int startBin,
	const unsigned int NUM_BINS, const double thresholdAmplitude);

foundBin findFundBin(const double * const ampl, const unsigned int NUM_BINS,
	const double avgMultThreshold, const unsigned int numPeaks);

void applyHanningWindow(const double * const inSamples, double * const outSamples, const unsigned int NUM_SAMPLES);

void computeAmplitudes(const double * const real, const double * const imag,
	double * const ampl, const unsigned int NUM_BINS);

double findTrueFreq(const unsigned int binIndex, const double phase1, const double phase2, const unsigned int osampOffset,
	const unsigned int FFT_LEN, const unsigned int SAMPLE_RATE);

foundFund findFundamental(const double * const samples, const unsigned int SAMPLES_LEN, const unsigned int FFT_LEN,
	const unsigned int osampOffset, const unsigned int SAMPLE_RATE, const unsigned int peakDetectThreshold,
	const unsigned int numPeaks);

#endif
